Learn R Programming

fmriqa (version 0.3.0)

fmriqa-package: fmriqa: fMRI quality assurance routines

Description

The fmriqa package provides an implementation of the fMRI quality assurance analysis protocol detailed by Friedman and Glover (2006) <doi:10.1002/jmri.20583>.

Arguments

Author

Maintainer: Martin Wilson martin@pipegrep.co.uk

Details

#' To learn more about fmriqa, start with the vignettes: `browseVignettes(package = "fmriqa")`

For a full list of functions: `help(package=fmriqa, help_type="html")`

See Also

Useful links: