Run fMRI quality assurance procedure on a NIfTI data file
run_fmriqa(
data_file = NULL,
roi_width = 21,
slice_num = NULL,
skip = 2,
tr = NULL,
pix_dim = NULL,
poly_det_ord = 3,
spike_detect = FALSE,
x_pos = NULL,
y_pos = NULL,
plot_title = NULL,
last_vol = NULL,
gen_png = TRUE,
gen_res_csv = TRUE,
gen_pdf = FALSE,
gen_spec_csv = FALSE,
png_fname = NULL,
res_fname = NULL,
pdf_fname = NULL,
spec_fname = NULL,
verbose = TRUE,
bg_smooth = 12,
bg_shrink = 25,
t1_canny = NULL,
t2_canny = NULL
)dataframe of QA metrics
input data in nifti format, a file chooser will open if not set
roi analysis region in pixels (default=21)
slice number for analysis (default=middle slice)
number of initial volumes to exclude from the analysis (default=2)
override the TR detected from data (seconds)
override the x,y,z pixel dimensions (mm) detected from data eg pixdim=c(3,3,3)
polynomial order used for detrending (default=3)
generate k-space spike-detection plot (default=FALSE)
x position of ROI (default=center of gravity)
y position of ROI (default=center of gravity)
add a title to the png and pdf plots
last volume number to use in the analysis
output png plot (default=TRUE)
output csv results (default=TRUE)
output pdf plot (default=FALSE)
output csv of spectral points (default=FALSE)
png plot filename
csv results filename
pdf plot filename
csv spectral data filename
provide text output while running (default=TRUE)
amount to smooth background image before calculating the maximum BG percent metric (default=12mm)
amount to shrink the BG image away from the object to avoid residual object signal in the maximum BG percent metric (default=25mm)
threshold for weak edges for Canny edge detector (defaults to auto detect)
threshold for strong edges for Canny edge detector (defaults to auto detect)
fname <- system.file("extdata", "qa_data.nii.gz", package = "fmriqa")
res <- run_fmriqa(data_file = fname, gen_png = FALSE, gen_res_csv = FALSE, tr = 3)
Run the code above in your browser using DataLab